import React from 'react';

var splitClassName = function splitClassName(className) {
  return className.split(/\s+/g);
};

var mapAndMergeClassNames = function mapAndMergeClassNames(className, namesMap) {
  var namesArray = Array.isArray(className) ? className : [className];
  var splitNamesArr = namesArray.flatMap(function (name) {
    return splitClassName(name);
  });
  return splitNamesArr.map(function (name) {
    var _namesMap$name;

    return (_namesMap$name = namesMap[name]) != null ? _namesMap$name : name;
  }).join(' ');
};

var getMappedProps = function getMappedProps(props, extraProps, namesMap) {
  var mappedProps = {};
  var propsToMap = Object.keys(props).filter(function (key) {
    return key === 'className' || extraProps.includes(key);
  });
  propsToMap.forEach(function (key) {
    mappedProps[key] = mapAndMergeClassNames(props[key], namesMap);
  });
  return mappedProps;
};

var patchClassNamesOfChildren = function patchClassNamesOfChildren(namesMap, extraProps, children) {
  return React.Children.map(children, function (child) {
    if (!React.isValidElement(child)) {
      return child;
    }

    var mappedProps = getMappedProps(child.props, extraProps, namesMap);
    var patchedChildren = patchClassNamesOfChildren(namesMap, extraProps, child.props.children);

    if (!Object.keys(mappedProps).length && !React.isValidElement(child.props.children)) {
      return child;
    }

    return React.cloneElement(child, mappedProps, patchedChildren);
  });
};

var PatchStyles = function PatchStyles(_ref) {
  var classNames = _ref.classNames,
      extraProps = _ref.extraProps,
      children = _ref.children;

  if (!children) {
    throw new Error('ApplyStyles should always have children to apply styles too');
  }

  var extraPropsArr = Array.isArray(extraProps) ? extraProps : [extraProps];
  var extraPropsSplit = extraPropsArr.flatMap(function (props) {
    return (props != null ? props : '').split(/\s*,\s*/g);
  });
  return React.createElement(React.Fragment, null, patchClassNamesOfChildren(classNames, extraPropsSplit, children));
};

export default PatchStyles;
//# sourceMappingURL=index.js.map
